Documentation
¶
Index ¶
Constants ¶
const ( ComposeAppPath = "/etc/compose/manifests" EmbeddedComposeAppPath = "/usr/local/etc/compose/manifests" )
Variables ¶
This section is empty.
Functions ¶
func ComposeVolumeName ¶ added in v1.1.0
ComposeVolumeName generates a unique Compose-compatible volume name based on the application and volume names.
func ComposeVolumeNames ¶
func ComposeVolumeNames(appName string, volumes []v1alpha1.ApplicationVolume) []string
ComposeVolumeNames returns the list of unique Compose-compatible volume names for the given application name and list of volumes.
func NewComposeID ¶ added in v0.6.0
NewComposeID generates a deterministic, lowercase, DNS-compatible ID with a fixed-length hash suffix.
Types ¶
type Action ¶
type Action struct {
// ID of the application
ID string
// Name of the application
Name string
// Environment variables to be passed to the manifest handler at runtime
EnvVars map[string]string
// Type of the action
Type ActionType
// AppType of the application
AppType v1alpha1.AppType
// Path to the application
Path string
// Embedded is true if the application is embedded in the device
Embedded bool
// Volumes is a list of volume names related to this application
Volumes []string
}
type ActionHandler ¶
type ActionHandlerType ¶
type ActionHandlerType string
const (
ActionHandlerCompose ActionHandlerType = "compose"
)
type ActionType ¶
type ActionType string
const ( ActionAdd ActionType = "add" ActionRemove ActionType = "remove" ActionUpdate ActionType = "update" )
Click to show internal directories.
Click to hide internal directories.