tracing

package
v0.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 24, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func StartSpan

func StartSpan(ctx context.Context, tracerName, spanName string, opts ...trace.SpanStartOption) (context.Context, trace.Span)

StartSpan creates a new span using the global tracer provider. It uses the provided context to determine the parent span (if any), and returns a new context and the started span. The span name is normalized to kebab-case.

Types

This section is empty.

Jump to