Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StartSpan ¶
func StartSpan(ctx context.Context, tracerName, spanName string, opts ...trace.SpanStartOption) (context.Context, trace.Span)
StartSpan creates a new span using the global tracer provider. It uses the provided context to determine the parent span (if any), and returns a new context and the started span. The span name is normalized to kebab-case.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.